# graphql-api-koa

[![npm version](https://img.shields.io/npm/v/graphql-api-koa.svg)](https://npm.im/graphql-api-koa) ![Licence](https://img.shields.io/npm/l/graphql-api-koa.svg) [![Github issues](https://img.shields.io/github/issues/jaydenseric/graphql-api-koa.svg)](https://github.com/jaydenseric/graphql-api-koa/issues) [![Github stars](https://img.shields.io/github/stars/jaydenseric/graphql-api-koa.svg)](https://github.com/jaydenseric/graphql-api-koa/stargazers) [![Travis status](https://img.shields.io/travis/jaydenseric/graphql-api-koa.svg)](https://travis-ci.org/jaydenseric/graphql-api-koa)

GraphQL API Koa middleware.

## Setup

Install with peer dependencies using [npm](https://npmjs.com):

```sh
npm install graphql-api-koa graphql
```

## API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

#### Table of Contents

- [errorHandler](#errorhandler)
  - [Examples](#examples)
- [execute](#execute)
  - [Parameters](#parameters)
- [Types](#types)
  - [ExecuteOptions](#executeoptions)
    - [Properties](#properties)
  - [MiddlewareOptionsOverride](#middlewareoptionsoverride)
    - [Parameters](#parameters-1)
    - [Examples](#examples-1)

### errorHandler

- **See: [GraphQL Draft RFC Specification October 2016 § 7.2.2](http://facebook.github.io/graphql/October2016/#sec-Errors).**
- **See: [http-errors on npm](https://npm.im/http-errors).**

Creates Koa middleware to handle errors. Use this middleware first to catch all errors for a correctly formated GraphQL response. For security, errors thrown outside resolvers without an `expose` property and `true` value are masked by a generic 500 error.

#### Examples

_A basic GraphQL API._

```javascript
import Koa from 'koa'
import bodyParser from 'koa-bodyparser'
import { errorHandler, execute } from 'graphql-api-koa'
import schema from './schema'

const app = new Koa()
  .use(errorHandler())
  .use(bodyParser())
  .use(execute({ schema }))
```

Returns **[Function](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function)** Koa middleware.

### execute

Creates Koa middleware to execute GraphQL. Use after the [errorHandler](#errorhandler) and [body parser](https://npm.im/koa-bodyparser) middleware.

#### Parameters

- `options` **[ExecuteOptions](#executeoptions)** Options.

Returns **[Function](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function)** Koa middleware.

### Types

The following types are for documentation only and are not exported.

#### ExecuteOptions

GraphQL [execute](#execute) Koa middleware options.

Type: [Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)

##### Properties

- `schema` **module:graphql.GraphQLSchema** GraphQL schema.
- `rootValue` **any?** Value passed to the first resolver.
- `contextValue` **any?** Execution context (usually an object) passed to resolvers.
- `fieldResolver` **[Function](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function)?** Custom default field resolver.
- `override` **[MiddlewareOptionsOverride](#middlewareoptionsoverride)?** Override any [ExecuteOptions](#executeoptions) (except `override`) per request.

#### MiddlewareOptionsOverride

Per-request Koa middleware options override.

Type: [Function](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function)

##### Parameters

- `context` **module:koa.Context** Koa context.

##### Examples

_[execute](#execute) middleware options setting the schema once at startup and user context per-request._

```javascript
import schema from './schema'

const executeOptions = {
  schema,
  override: ctx => ({
    contextValue: {
      user: ctx.user
    }
  })
}
```

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** Options.
